@@ -144,6 +144,9 @@ static double GetEdgeBackgroundCensus(const Image *image,
   const char
     *artifact;
 
+  const Quantum
+    *p;
+
   double
     census;
 
@@ -157,9 +160,6 @@ static double GetEdgeBackgroundCensus(const Image *image,
   RectangleInfo
     edge_geometry;
 
-  const Quantum
-    *p;
-
   ssize_t
     y;
 
@@ -423,8 +423,8 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   artifact=GetImageArtifact(image, "trim:edges");
   if (artifact == (const char *) NULL)
     {
-      bounds.width=image->columns == 1 ? 1 : 0;
-      bounds.height=image->rows == 1 ? 1 : 0;
+      bounds.width=(size_t) (image->columns == 1 ? 1 : 0);
+      bounds.height=(size_t) (image->rows == 1 ? 1 : 0);
       bounds.x=(ssize_t) image->columns;
       bounds.y=(ssize_t) image->rows;
     }
